@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -208,7 +208,7 @@ func getCRC(data []byte) []uint8 {
 
 	crc = (^crc) & eof16
 
-	return parseCRC([]byte{byte(crc & eof), byte(crc >> checkSumSecondDeviation)})
+	return parseCRC([]uint8{uint8(crc & eof), uint8(crc >> checkSumSecondDeviation)})
 }
 
 // parseCRC bytes above 0xf8 must be preceded with and 0xfd byte and XORed with 0x20 byte.
